@@ -7,7 +7,7 @@ use parent qw(Exporter);
 use Data::Printer;
 use List::Util qw(any);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 our @EXPORT = qw(bt);
 
 our $Indent = '  ';
@@ -18,6 +18,9 @@ our $Skiplevels = 0;
 our %IgnorePkg;
 our %Opts = (
     colored		=> 1,
+    colors		=> {
+	    brackets    => ''
+    },
     class 		=> {
         internals       => 1,
         show_methods    => 'none',
